Struct sdl2::messagebox::MessageBoxFlag [−]
pub struct MessageBoxFlag { /* fields omitted */ }Methods
impl MessageBoxFlag
impl MessageBoxFlagpub fn empty() -> MessageBoxFlag
pub fn empty() -> MessageBoxFlagReturns an empty set of flags.
pub fn all() -> MessageBoxFlag
pub fn all() -> MessageBoxFlagReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<MessageBoxFlag>
pub fn from_bits(bits: u32) -> Option<MessageBoxFlag>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> MessageBoxFlag
pub fn from_bits_truncate(bits: u32) -> MessageBoxFlagConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: MessageBoxFlag) -> bool
pub fn intersects(&self, other: MessageBoxFlag) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: MessageBoxFlag) -> bool
pub fn contains(&self, other: MessageBoxFlag) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: MessageBoxFlag)
pub fn insert(&mut self, other: MessageBoxFlag)Inserts the specified flags in-place.
pub fn remove(&mut self, other: MessageBoxFlag)
pub fn remove(&mut self, other: MessageBoxFlag)Removes the specified flags in-place.
pub fn toggle(&mut self, other: MessageBoxFlag)
pub fn toggle(&mut self, other: MessageBoxFlag)Toggles the specified flags in-place.